# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: project.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import analysis_config_pb2 as analysis__config__pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__version__pb2 = analysis__config__pb2.analysis__version__pb2
except AttributeError:
  analysis__version__pb2 = analysis__config__pb2.analysis_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__config__pb2 = analysis__config__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = analysis__config__pb2.algorithm_config_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
from terrascope_api.models import analysis_computation_pb2 as analysis__computation__pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__computation__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__computation__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
from terrascope_api.models import aoi_collection_pb2 as aoi__collection__pb2
try:
  common__models__pb2 = aoi__collection__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__collection__pb2.common_models_pb2
from terrascope_api.models import result_pb2 as result__pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
try:
  toi__pb2 = result__pb2.toi__pb2
except AttributeError:
  toi__pb2 = result__pb2.toi_pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_config_pb2 import *
from terrascope_api.models.analysis_computation_pb2 import *
from terrascope_api.models.aoi_collection_pb2 import *
from terrascope_api.models.result_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rproject.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15\x61nalysis_config.proto\x1a\x1a\x61nalysis_computation.proto\x1a\x14\x61oi_collection.proto\x1a\x0cresult.proto\"\x99\x05\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12.\n\x06status\x18\x05 \x01(\x0e\x32\x1e.oi.papi.Project.ProjectStatus\x12/\n\x0f\x61oi_collections\x18\x06 \x03(\x0b\x32\x16.oi.papi.AOICollection\x12;\n\x15\x61nalysis_computations\x18\x07 \x03(\x0b\x32\x1c.oi.papi.AnalysisComputation\x12\x31\n\x10\x61nalysis_configs\x18\x08 \x03(\x0b\x32\x17.oi.papi.AnalysisConfig\x12.\n\nstart_date\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_ts\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x18\x61vailable_result_filters\x18\x0c \x03(\x0b\x32\x1c.oi.papi.ProjectResultFilter\x12<\n\x16\x61pplied_result_filters\x18\r \x03(\x0b\x32\x1c.oi.papi.ProjectResultFilter\"q\n\rProjectStatus\x12\x1a\n\x16UNKNOWN_PROJECT_STATUS\x10\x00\x12\r\n\tCOMPLETED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\x12\x0f\n\x0bNOT_STARTED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\"s\n\x0cProjectGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\"\n\x08projects\x18\x03 \x03(\x0b\x32\x10.oi.papi.Project\x12\x11\n\tcollapsed\x18\x04 \x01(\x08\x12\x12\n\nsort_order\x18\x05 \x01(\r\"\xd5\x01\n\x13ProjectCollaborator\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x36\n\x04role\x18\x02 \x01(\x0e\x32(.oi.papi.ProjectCollaborator.ProjectRole\x12\x13\n\x0b\x63ustomer_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"R\n\x0bProjectRole\x12\x18\n\x14UNKNOWN_PROJECT_ROLE\x10\x00\x12\x0b\n\x07\x43REATOR\x10\x01\x12\x10\n\x0c\x43OLLABORATOR\x10\x02\x12\n\n\x06VIEWER\x10\x03\"\x7f\n\x13ProjectResultFilter\x12%\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x15.oi.papi.ResultFilter\x12\x1a\n\x12\x61nalysis_config_id\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\"=\n\x12ProjectListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\"w\n\x13ProjectListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\"\n\x08projects\x18\x02 \x03(\x0b\x32\x10.oi.papi.Project\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x1f\n\x11ProjectGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"L\n\x12ProjectGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\"9\n\x14ProjectCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"O\n\x15ProjectCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\":\n\x14ProjectUpdateRequest\x12\"\n\x08projects\x18\x01 \x03(\x0b\x32\x10.oi.papi.Project\",\n\x15ProjectUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"#\n\x14ProjectDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\",\n\x15ProjectDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\" \n\x11ProjectRunRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\")\n\x12ProjectRunResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"!\n\x13ProjectCloneRequest\x12\n\n\x02id\x18\x01 \x01(\t\"N\n\x14ProjectCloneResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\"g\n\'ProjectResultFilterMappingCreateRequest\x12<\n\x16project_result_filters\x18\x01 \x03(\x0b\x32\x1c.oi.papi.ProjectResultFilter\"?\n(ProjectResultFilterMappingCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"g\n\'ProjectResultFilterMappingDeleteRequest\x12<\n\x16project_result_filters\x18\x01 \x03(\x0b\x32\x1c.oi.papi.ProjectResultFilter\"?\n(ProjectResultFilterMappingDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"B\n\x17ProjectGroupListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x87\x01\n\x18ProjectGroupListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12-\n\x0eproject_groups\x18\x02 \x03(\x0b\x32\x15.oi.papi.ProjectGroup\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\">\n\x19ProjectGroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bproject_ids\x18\x02 \x03(\t\"_\n\x1aProjectGroupCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\rproject_group\x18\x02 \x01(\x0b\x32\x15.oi.papi.ProjectGroup\"(\n\x19ProjectGroupDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"1\n\x1aProjectGroupDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"{\n\x19ProjectGroupUpdateRequest\x12-\n\x0eproject_groups\x18\x01 \x03(\x0b\x32\x15.oi.papi.ProjectGroup\x12\x17\n\x0fupdate_projects\x18\x02 \x01(\x08\x12\x16\n\x0eupdate_details\x18\x03 \x01(\x08\"1\n\x1aProjectGroupUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"3\n\x1dProjectCollaboratorGetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"r\n\x1eProjectCollaboratorGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12;\n\x15project_collaborators\x18\x02 \x03(\x0b\x32\x1c.oi.papi.ProjectCollaborator\"s\n ProjectCollaboratorUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12;\n\x15project_collaborators\x18\x02 \x03(\x0b\x32\x1c.oi.papi.ProjectCollaborator\"8\n!ProjectCollaboratorUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"H\n ProjectCollaboratorDeleteRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x10\n\x08user_ids\x18\x02 \x03(\t\"8\n!ProjectCollaboratorDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xab\x0b\n\nProjectApi\x12\x41\n\x04list\x12\x1b.oi.papi.ProjectListRequest\x1a\x1c.oi.papi.ProjectListResponse\x12>\n\x03get\x12\x1a.oi.papi.ProjectGetRequest\x1a\x1b.oi.papi.ProjectGetResponse\x12G\n\x06\x63reate\x12\x1d.oi.papi.ProjectCreateRequest\x1a\x1e.oi.papi.ProjectCreateResponse\x12G\n\x06update\x12\x1d.oi.papi.ProjectUpdateRequest\x1a\x1e.oi.papi.ProjectUpdateResponse\x12G\n\x06\x64\x65lete\x12\x1d.oi.papi.ProjectDeleteRequest\x1a\x1e.oi.papi.ProjectDeleteResponse\x12>\n\x03run\x12\x1a.oi.papi.ProjectRunRequest\x1a\x1b.oi.papi.ProjectRunResponse\x12\x8b\x01\n$create_project_result_filter_mapping\x12\x30.oi.papi.ProjectResultFilterMappingCreateRequest\x1a\x31.oi.papi.ProjectResultFilterMappingCreateResponse\x12\x8b\x01\n$delete_project_result_filter_mapping\x12\x30.oi.papi.ProjectResultFilterMappingDeleteRequest\x1a\x31.oi.papi.ProjectResultFilterMappingDeleteResponse\x12\x44\n\x05\x63lone\x12\x1c.oi.papi.ProjectCloneRequest\x1a\x1d.oi.papi.ProjectCloneResponse\x12Q\n\nlist_group\x12 .oi.papi.ProjectGroupListRequest\x1a!.oi.papi.ProjectGroupListResponse\x12W\n\x0c\x63reate_group\x12\".oi.papi.ProjectGroupCreateRequest\x1a#.oi.papi.ProjectGroupCreateResponse\x12W\n\x0c\x64\x65lete_group\x12\".oi.papi.ProjectGroupDeleteRequest\x1a#.oi.papi.ProjectGroupDeleteResponse\x12W\n\x0cupdate_group\x12\".oi.papi.ProjectGroupUpdateRequest\x1a#.oi.papi.ProjectGroupUpdateResponse\x12\x63\n\x10get_collaborator\x12&.oi.papi.ProjectCollaboratorGetRequest\x1a\'.oi.papi.ProjectCollaboratorGetResponse\x12l\n\x13update_collaborator\x12).oi.papi.ProjectCollaboratorUpdateRequest\x1a*.oi.papi.ProjectCollaboratorUpdateResponse\x12l\n\x13\x64\x65lete_collaborator\x12).oi.papi.ProjectCollaboratorDeleteRequest\x1a*.oi.papi.ProjectCollaboratorDeleteResponseP\x00P\x02P\x03P\x04P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECT']._serialized_start=168
  _globals['_PROJECT']._serialized_end=833
  _globals['_PROJECT_PROJECTSTATUS']._serialized_start=720
  _globals['_PROJECT_PROJECTSTATUS']._serialized_end=833
  _globals['_PROJECTGROUP']._serialized_start=835
  _globals['_PROJECTGROUP']._serialized_end=950
  _globals['_PROJECTCOLLABORATOR']._serialized_start=953
  _globals['_PROJECTCOLLABORATOR']._serialized_end=1166
  _globals['_PROJECTCOLLABORATOR_PROJECTROLE']._serialized_start=1084
  _globals['_PROJECTCOLLABORATOR_PROJECTROLE']._serialized_end=1166
  _globals['_PROJECTRESULTFILTER']._serialized_start=1168
  _globals['_PROJECTRESULTFILTER']._serialized_end=1295
  _globals['_PROJECTLISTREQUEST']._serialized_start=1297
  _globals['_PROJECTLISTREQUEST']._serialized_end=1358
  _globals['_PROJECTLISTRESPONSE']._serialized_start=1360
  _globals['_PROJECTLISTRESPONSE']._serialized_end=1479
  _globals['_PROJECTGETREQUEST']._serialized_start=1481
  _globals['_PROJECTGETREQUEST']._serialized_end=1512
  _globals['_PROJECTGETRESPONSE']._serialized_start=1514
  _globals['_PROJECTGETRESPONSE']._serialized_end=1590
  _globals['_PROJECTCREATEREQUEST']._serialized_start=1592
  _globals['_PROJECTCREATEREQUEST']._serialized_end=1649
  _globals['_PROJECTCREATERESPONSE']._serialized_start=1651
  _globals['_PROJECTCREATERESPONSE']._serialized_end=1730
  _globals['_PROJECTUPDATEREQUEST']._serialized_start=1732
  _globals['_PROJECTUPDATEREQUEST']._serialized_end=1790
  _globals['_PROJECTUPDATERESPONSE']._serialized_start=1792
  _globals['_PROJECTUPDATERESPONSE']._serialized_end=1836
  _globals['_PROJECTDELETEREQUEST']._serialized_start=1838
  _globals['_PROJECTDELETEREQUEST']._serialized_end=1873
  _globals['_PROJECTDELETERESPONSE']._serialized_start=1875
  _globals['_PROJECTDELETERESPONSE']._serialized_end=1919
  _globals['_PROJECTRUNREQUEST']._serialized_start=1921
  _globals['_PROJECTRUNREQUEST']._serialized_end=1953
  _globals['_PROJECTRUNRESPONSE']._serialized_start=1955
  _globals['_PROJECTRUNRESPONSE']._serialized_end=1996
  _globals['_PROJECTCLONEREQUEST']._serialized_start=1998
  _globals['_PROJECTCLONEREQUEST']._serialized_end=2031
  _globals['_PROJECTCLONERESPONSE']._serialized_start=2033
  _globals['_PROJECTCLONERESPONSE']._serialized_end=2111
  _globals['_PROJECTRESULTFILTERMAPPINGCREATEREQUEST']._serialized_start=2113
  _globals['_PROJECTRESULTFILTERMAPPINGCREATEREQUEST']._serialized_end=2216
  _globals['_PROJECTRESULTFILTERMAPPINGCREATERESPONSE']._serialized_start=2218
  _globals['_PROJECTRESULTFILTERMAPPINGCREATERESPONSE']._serialized_end=2281
  _globals['_PROJECTRESULTFILTERMAPPINGDELETEREQUEST']._serialized_start=2283
  _globals['_PROJECTRESULTFILTERMAPPINGDELETEREQUEST']._serialized_end=2386
  _globals['_PROJECTRESULTFILTERMAPPINGDELETERESPONSE']._serialized_start=2388
  _globals['_PROJECTRESULTFILTERMAPPINGDELETERESPONSE']._serialized_end=2451
  _globals['_PROJECTGROUPLISTREQUEST']._serialized_start=2453
  _globals['_PROJECTGROUPLISTREQUEST']._serialized_end=2519
  _globals['_PROJECTGROUPLISTRESPONSE']._serialized_start=2522
  _globals['_PROJECTGROUPLISTRESPONSE']._serialized_end=2657
  _globals['_PROJECTGROUPCREATEREQUEST']._serialized_start=2659
  _globals['_PROJECTGROUPCREATEREQUEST']._serialized_end=2721
  _globals['_PROJECTGROUPCREATERESPONSE']._serialized_start=2723
  _globals['_PROJECTGROUPCREATERESPONSE']._serialized_end=2818
  _globals['_PROJECTGROUPDELETEREQUEST']._serialized_start=2820
  _globals['_PROJECTGROUPDELETEREQUEST']._serialized_end=2860
  _globals['_PROJECTGROUPDELETERESPONSE']._serialized_start=2862
  _globals['_PROJECTGROUPDELETERESPONSE']._serialized_end=2911
  _globals['_PROJECTGROUPUPDATEREQUEST']._serialized_start=2913
  _globals['_PROJECTGROUPUPDATEREQUEST']._serialized_end=3036
  _globals['_PROJECTGROUPUPDATERESPONSE']._serialized_start=3038
  _globals['_PROJECTGROUPUPDATERESPONSE']._serialized_end=3087
  _globals['_PROJECTCOLLABORATORGETREQUEST']._serialized_start=3089
  _globals['_PROJECTCOLLABORATORGETREQUEST']._serialized_end=3140
  _globals['_PROJECTCOLLABORATORGETRESPONSE']._serialized_start=3142
  _globals['_PROJECTCOLLABORATORGETRESPONSE']._serialized_end=3256
  _globals['_PROJECTCOLLABORATORUPDATEREQUEST']._serialized_start=3258
  _globals['_PROJECTCOLLABORATORUPDATEREQUEST']._serialized_end=3373
  _globals['_PROJECTCOLLABORATORUPDATERESPONSE']._serialized_start=3375
  _globals['_PROJECTCOLLABORATORUPDATERESPONSE']._serialized_end=3431
  _globals['_PROJECTCOLLABORATORDELETEREQUEST']._serialized_start=3433
  _globals['_PROJECTCOLLABORATORDELETEREQUEST']._serialized_end=3505
  _globals['_PROJECTCOLLABORATORDELETERESPONSE']._serialized_start=3507
  _globals['_PROJECTCOLLABORATORDELETERESPONSE']._serialized_end=3563
  _globals['_PROJECTAPI']._serialized_start=3566
  _globals['_PROJECTAPI']._serialized_end=5017
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import project_pb2 as project__pb2

GRPC_GENERATED_VERSION = '1.63.0'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in project_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class ProjectApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.list = channel.unary_unary(
                '/oi.papi.ProjectApi/list',
                request_serializer=project__pb2.ProjectListRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectListResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.ProjectApi/get',
                request_serializer=project__pb2.ProjectGetRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectGetResponse.FromString,
                _registered_method=True)
        self.create = channel.unary_unary(
                '/oi.papi.ProjectApi/create',
                request_serializer=project__pb2.ProjectCreateRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectCreateResponse.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/oi.papi.ProjectApi/update',
                request_serializer=project__pb2.ProjectUpdateRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectUpdateResponse.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/oi.papi.ProjectApi/delete',
                request_serializer=project__pb2.ProjectDeleteRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectDeleteResponse.FromString,
                _registered_method=True)
        self.run = channel.unary_unary(
                '/oi.papi.ProjectApi/run',
                request_serializer=project__pb2.ProjectRunRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectRunResponse.FromString,
                _registered_method=True)
        self.create_project_result_filter_mapping = channel.unary_unary(
                '/oi.papi.ProjectApi/create_project_result_filter_mapping',
                request_serializer=project__pb2.ProjectResultFilterMappingCreateRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectResultFilterMappingCreateResponse.FromString,
                _registered_method=True)
        self.delete_project_result_filter_mapping = channel.unary_unary(
                '/oi.papi.ProjectApi/delete_project_result_filter_mapping',
                request_serializer=project__pb2.ProjectResultFilterMappingDeleteRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectResultFilterMappingDeleteResponse.FromString,
                _registered_method=True)
        self.clone = channel.unary_unary(
                '/oi.papi.ProjectApi/clone',
                request_serializer=project__pb2.ProjectCloneRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectCloneResponse.FromString,
                _registered_method=True)
        self.list_group = channel.unary_unary(
                '/oi.papi.ProjectApi/list_group',
                request_serializer=project__pb2.ProjectGroupListRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectGroupListResponse.FromString,
                _registered_method=True)
        self.create_group = channel.unary_unary(
                '/oi.papi.ProjectApi/create_group',
                request_serializer=project__pb2.ProjectGroupCreateRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectGroupCreateResponse.FromString,
                _registered_method=True)
        self.delete_group = channel.unary_unary(
                '/oi.papi.ProjectApi/delete_group',
                request_serializer=project__pb2.ProjectGroupDeleteRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectGroupDeleteResponse.FromString,
                _registered_method=True)
        self.update_group = channel.unary_unary(
                '/oi.papi.ProjectApi/update_group',
                request_serializer=project__pb2.ProjectGroupUpdateRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectGroupUpdateResponse.FromString,
                _registered_method=True)
        self.get_collaborator = channel.unary_unary(
                '/oi.papi.ProjectApi/get_collaborator',
                request_serializer=project__pb2.ProjectCollaboratorGetRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectCollaboratorGetResponse.FromString,
                _registered_method=True)
        self.update_collaborator = channel.unary_unary(
                '/oi.papi.ProjectApi/update_collaborator',
                request_serializer=project__pb2.ProjectCollaboratorUpdateRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectCollaboratorUpdateResponse.FromString,
                _registered_method=True)
        self.delete_collaborator = channel.unary_unary(
                '/oi.papi.ProjectApi/delete_collaborator',
                request_serializer=project__pb2.ProjectCollaboratorDeleteRequest.SerializeToString,
                response_deserializer=project__pb2.ProjectCollaboratorDeleteResponse.FromString,
                _registered_method=True)


class ProjectApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def list(self, request, context):
        """
        List the Projects available to the user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get a specified Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create(self, request, context):
        """
        Create a Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Update a Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        Delete a Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def run(self, request, context):
        """
        Run a Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_project_result_filter_mapping(self, request, context):
        """
        Create a project result filter mapping
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_project_result_filter_mapping(self, request, context):
        """
        Delete a project result filter mapping
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def clone(self, request, context):
        """
        Clone a Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_group(self, request, context):
        """
        List Project Groups
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_group(self, request, context):
        """
        Create Project Groups
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_group(self, request, context):
        """
        Delete Project Groups
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_group(self, request, context):
        """
        Update Project Groups
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_collaborator(self, request, context):
        """
        Get Project Collaborators
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_collaborator(self, request, context):
        """
        Create Project Collaborators
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_collaborator(self, request, context):
        """
        Delete Project Collaborators
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=project__pb2.ProjectListRequest.FromString,
                    response_serializer=project__pb2.ProjectListResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=project__pb2.ProjectGetRequest.FromString,
                    response_serializer=project__pb2.ProjectGetResponse.SerializeToString,
            ),
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=project__pb2.ProjectCreateRequest.FromString,
                    response_serializer=project__pb2.ProjectCreateResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=project__pb2.ProjectUpdateRequest.FromString,
                    response_serializer=project__pb2.ProjectUpdateResponse.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=project__pb2.ProjectDeleteRequest.FromString,
                    response_serializer=project__pb2.ProjectDeleteResponse.SerializeToString,
            ),
            'run': grpc.unary_unary_rpc_method_handler(
                    servicer.run,
                    request_deserializer=project__pb2.ProjectRunRequest.FromString,
                    response_serializer=project__pb2.ProjectRunResponse.SerializeToString,
            ),
            'create_project_result_filter_mapping': grpc.unary_unary_rpc_method_handler(
                    servicer.create_project_result_filter_mapping,
                    request_deserializer=project__pb2.ProjectResultFilterMappingCreateRequest.FromString,
                    response_serializer=project__pb2.ProjectResultFilterMappingCreateResponse.SerializeToString,
            ),
            'delete_project_result_filter_mapping': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_project_result_filter_mapping,
                    request_deserializer=project__pb2.ProjectResultFilterMappingDeleteRequest.FromString,
                    response_serializer=project__pb2.ProjectResultFilterMappingDeleteResponse.SerializeToString,
            ),
            'clone': grpc.unary_unary_rpc_method_handler(
                    servicer.clone,
                    request_deserializer=project__pb2.ProjectCloneRequest.FromString,
                    response_serializer=project__pb2.ProjectCloneResponse.SerializeToString,
            ),
            'list_group': grpc.unary_unary_rpc_method_handler(
                    servicer.list_group,
                    request_deserializer=project__pb2.ProjectGroupListRequest.FromString,
                    response_serializer=project__pb2.ProjectGroupListResponse.SerializeToString,
            ),
            'create_group': grpc.unary_unary_rpc_method_handler(
                    servicer.create_group,
                    request_deserializer=project__pb2.ProjectGroupCreateRequest.FromString,
                    response_serializer=project__pb2.ProjectGroupCreateResponse.SerializeToString,
            ),
            'delete_group': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_group,
                    request_deserializer=project__pb2.ProjectGroupDeleteRequest.FromString,
                    response_serializer=project__pb2.ProjectGroupDeleteResponse.SerializeToString,
            ),
            'update_group': grpc.unary_unary_rpc_method_handler(
                    servicer.update_group,
                    request_deserializer=project__pb2.ProjectGroupUpdateRequest.FromString,
                    response_serializer=project__pb2.ProjectGroupUpdateResponse.SerializeToString,
            ),
            'get_collaborator': grpc.unary_unary_rpc_method_handler(
                    servicer.get_collaborator,
                    request_deserializer=project__pb2.ProjectCollaboratorGetRequest.FromString,
                    response_serializer=project__pb2.ProjectCollaboratorGetResponse.SerializeToString,
            ),
            'update_collaborator': grpc.unary_unary_rpc_method_handler(
                    servicer.update_collaborator,
                    request_deserializer=project__pb2.ProjectCollaboratorUpdateRequest.FromString,
                    response_serializer=project__pb2.ProjectCollaboratorUpdateResponse.SerializeToString,
            ),
            'delete_collaborator': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_collaborator,
                    request_deserializer=project__pb2.ProjectCollaboratorDeleteRequest.FromString,
                    response_serializer=project__pb2.ProjectCollaboratorDeleteResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.ProjectApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/list',
            project__pb2.ProjectListRequest.SerializeToString,
            project__pb2.ProjectListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/get',
            project__pb2.ProjectGetRequest.SerializeToString,
            project__pb2.ProjectGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/create',
            project__pb2.ProjectCreateRequest.SerializeToString,
            project__pb2.ProjectCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/update',
            project__pb2.ProjectUpdateRequest.SerializeToString,
            project__pb2.ProjectUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/delete',
            project__pb2.ProjectDeleteRequest.SerializeToString,
            project__pb2.ProjectDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def run(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/run',
            project__pb2.ProjectRunRequest.SerializeToString,
            project__pb2.ProjectRunResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create_project_result_filter_mapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/create_project_result_filter_mapping',
            project__pb2.ProjectResultFilterMappingCreateRequest.SerializeToString,
            project__pb2.ProjectResultFilterMappingCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete_project_result_filter_mapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/delete_project_result_filter_mapping',
            project__pb2.ProjectResultFilterMappingDeleteRequest.SerializeToString,
            project__pb2.ProjectResultFilterMappingDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def clone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/clone',
            project__pb2.ProjectCloneRequest.SerializeToString,
            project__pb2.ProjectCloneResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/list_group',
            project__pb2.ProjectGroupListRequest.SerializeToString,
            project__pb2.ProjectGroupListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/create_group',
            project__pb2.ProjectGroupCreateRequest.SerializeToString,
            project__pb2.ProjectGroupCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/delete_group',
            project__pb2.ProjectGroupDeleteRequest.SerializeToString,
            project__pb2.ProjectGroupDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/update_group',
            project__pb2.ProjectGroupUpdateRequest.SerializeToString,
            project__pb2.ProjectGroupUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_collaborator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/get_collaborator',
            project__pb2.ProjectCollaboratorGetRequest.SerializeToString,
            project__pb2.ProjectCollaboratorGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update_collaborator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/update_collaborator',
            project__pb2.ProjectCollaboratorUpdateRequest.SerializeToString,
            project__pb2.ProjectCollaboratorUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete_collaborator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectApi/delete_collaborator',
            project__pb2.ProjectCollaboratorDeleteRequest.SerializeToString,
            project__pb2.ProjectCollaboratorDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
